==> uzh-appi-1.0.tar.gz: uzh-appi-1.0/setup.py <==
from distutils.core import setup

setup(
    name="uzh-appi",  # How you named your package folder (MyLib)
    packages=["appi"],  # Chose the same as "name"
    version="1.0",  # Start with a small number and increase it with every change you make
    license="MIT",  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description="Dummy Project",  # Give a short description about your library
    author="Philipp Glor",  # Type in your name
    author_email="philipp.gloor@uzh.ch",  # Type in your E-Mail
    url="https://github.com/fibbo/uzh-appi",  # Provide either the link to your github or to your website
    download_url="https://github.com/fibbo/uzh-appi/archive/refs/tags/1.0.tar.gz",  # I explain this later on
    keywords=[
        "DUMMY",
        "DONTDOWNLOAD",
    ],  # Keywords that define your package best
    install_requires=[],  # I get to this in a second
    classifiers=[
        "Development Status :: 3 - Alpha",  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        "Intended Audience :: Developers",  # Define that your audience are developers
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",  # Again, pick a license
        "Programming Language :: Python :: 3",  # Specify which pyhton versions that you want to support
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)

==> uzh-appi-1.1.tar.gz: uzh-appi-1.1/setup.py <==
from distutils.core import setup

setup(
    name="uzh-appi",  # How you named your package folder (MyLib)
    packages=["appi"],  # Chose the same as "name"
    version="1.1",  # Start with a small number and increase it with every change you make
    license="MIT",  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description="Dummy Project",  # Give a short description about your library
    author="Philipp Gloor",  # Type in your name
    author_email="philipp.gloor@uzh.ch",  # Type in your E-Mail
    url="https://github.com/fibbo/uzh-appi",  # Provide either the link to your github or to your website
    download_url="https://github.com/fibbo/uzh-appi/archive/refs/tags/1.1tar.gz",  # I explain this later on
    keywords=[
        "DUMMY",
        "DONTDOWNLOAD",
    ],  # Keywords that define your package best
    install_requires=[],  # I get to this in a second
    classifiers=[
        "Development Status :: 3 - Alpha",  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        "Intended Audience :: Developers",  # Define that your audience are developers
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",  # Again, pick a license
        "Programming Language :: Python :: 3",  # Specify which pyhton versions that you want to support
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)
